﻿//Copyright © 2021 by ANTRAS GmbH, covered by AGPL-3.0-or-later
using System.Collections.Generic;
using System;
using System.IO;
using System.Diagnostics;
using System.Text.RegularExpressions;

namespace ANTRAS.PdfConversion.service.helper {
	public static class Helper {
		public static bool TryToGuaranteePath(string path) {
			bool ret = false;
			if(!string.IsNullOrWhiteSpace(path)) {
				DirectoryInfo di = new DirectoryInfo(path);
				if(di.Exists) {
					ret = true;
				} else {
					if(di.Parent != null) {
						if(TryToGuaranteePath(di.Parent.FullName)) {
							try {
								Directory.CreateDirectory(path);
								ret = true;
							} catch(Exception ex) {
								EventLog.WriteEntry("ANTRAS.PdfConversion.Service"
									, string.Format("DirectoryHelper.TryToGuaranteePath(): cannot CreateDirectory: {0}. {1}. {2}", path, ex.Message, ex.StackTrace)
									, EventLogEntryType.Error
									, 0
									);
							}
						}
					}
				}
			}
			return ret;
		}

		private static Regex _isNumber = new Regex(@"^\d+$");
		public static bool IsInteger(string value) {
			bool ret = false;
			if(!string.IsNullOrWhiteSpace(value)) {
				Match m;
				if(value.StartsWith("-")) {
					m = _isNumber.Match(value.Substring(1));
				} else {
					m = _isNumber.Match(value);
				}
				ret = m.Success;
			}
			return ret;
		}

		public static string GetRandomFilename(string ext) {
			return !string.IsNullOrWhiteSpace(ext) ?
				string.Format("{0}.{1}", Guid.NewGuid().ToString(), ext)
				: Guid.NewGuid().ToString();
		}

		public static bool IsFileA_newerThan_B(string fileA, string fileB) {
			bool ret = false;
			FileInfo a = new FileInfo(fileA);
			if(a.Exists) {
				FileInfo b = new FileInfo(fileB);
				if(b.Exists) {
					ret = a.LastWriteTime > b.LastWriteTime;
				}
			}
			return ret;
		}
	}
	public class IntList : List<int> {
		public IntList()
			: base() {
		}
	}
	public class StringList : List<string> {
		public StringList()
			: base() {
		}
	}
}
